@@ -9,7 +9,7 @@
 #
 package Config::Model::Tk::ListEditor ;
 BEGIN {
-  $Config::Model::Tk::ListEditor::VERSION = '1.320';
+  $Config::Model::Tk::ListEditor::VERSION = '1.321';
 }
 
 use strict;
@@ -29,7 +29,7 @@ Construct Tk::Widget 'ConfigModelListEditor';
 my @fbe1 = qw/-fill both -expand 1/ ;
 my @fxe1 = qw/-fill x    -expand 1/ ;
 my @fx   = qw/-fill    x / ;
-my $logger = Log::Log4perl::get_logger(__PACKAGE__);
+my $logger = Log::Log4perl::get_logger("Tk::ListEditor");
 
 my $up_img;
 my $down_img;
